@@ -1,21 +1,22 @@
 /* init.c --- Initialization functions.
- * Copyright (C) 2002, 2003, 2004, 2006  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
  *
  * This file is part of Shishi.
  *
- * Shishi is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * Shishi is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
- * Shishi is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * Shishi is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Shishi; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ * along with Shishi; if not, see http://www.gnu.org/licenses or write
+ * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
+ * Floor, Boston, MA 02110-1301, USA
  *
  */
 
@@ -264,15 +265,29 @@ init_read (Shishi * handle,
   /* XXX Is this the correct place for this? */
   maybe_install_usercfg (handle);
 
-  if (!tktsfile)
-    tktsfile = shishi_tkts_default_file (handle);
-
   if (!systemcfgfile)
     systemcfgfile = shishi_cfg_default_systemfile (handle);
 
+  if (*systemcfgfile)
+    rc = shishi_cfg_from_file (handle, systemcfgfile);
+  if (rc == SHISHI_FOPEN_ERROR)
+    shishi_warn (handle, "%s: %s", systemcfgfile, strerror (errno));
+  if (rc != SHISHI_OK && rc != SHISHI_FOPEN_ERROR)
+    return rc;
+
   if (!usercfgfile)
     usercfgfile = shishi_cfg_default_userfile (handle);
 
+  if (*usercfgfile)
+    rc = shishi_cfg_from_file (handle, usercfgfile);
+  if (rc == SHISHI_FOPEN_ERROR)
+    shishi_warn (handle, "%s: %s", usercfgfile, strerror (errno));
+  if (rc != SHISHI_OK && rc != SHISHI_FOPEN_ERROR)
+    return rc;
+
+  if (!tktsfile)
+    tktsfile = shishi_tkts_default_file (handle);
+
   if (!handle->tkts)
     rc = shishi_tkts (handle, &handle->tkts);
   if (rc != SHISHI_OK)
@@ -281,21 +296,7 @@ init_read (Shishi * handle,
   if (*tktsfile)
     rc = shishi_tkts_from_file (handle->tkts, tktsfile);
   if (rc == SHISHI_FOPEN_ERROR)
-    shishi_warn (handle, "%s: %s", tktsfile, strerror (errno));
-  if (rc != SHISHI_OK && rc != SHISHI_FOPEN_ERROR)
-    return rc;
-
-  if (*systemcfgfile)
-    rc = shishi_cfg_from_file (handle, systemcfgfile);
-  if (rc == SHISHI_FOPEN_ERROR)
-    shishi_warn (handle, "%s: %s", systemcfgfile, strerror (errno));
-  if (rc != SHISHI_OK && rc != SHISHI_FOPEN_ERROR)
-    return rc;
-
-  if (*usercfgfile)
-    rc = shishi_cfg_from_file (handle, usercfgfile);
-  if (rc == SHISHI_FOPEN_ERROR)
-    shishi_warn (handle, "%s: %s", usercfgfile, strerror (errno));
+    shishi_verbose (handle, "%s: %s", tktsfile, strerror (errno));
   if (rc != SHISHI_OK && rc != SHISHI_FOPEN_ERROR)
     return rc;
 
