@@ -1,5 +1,5 @@
 /* tkts.c --- Ticket set handling.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -21,6 +21,7 @@
  */
 
 #include "internal.h"
+#include <minmax.h>
 
 struct Shishi_tkts
 {
@@ -176,7 +177,7 @@ shishi_tkts_done (Shishi_tkts ** tkts)
 int
 shishi_tkts_size (Shishi_tkts * tkts)
 {
-  return tkts->ntkts;
+  return tkts ? tkts->ntkts : -1;
 }
 
 /**
@@ -404,6 +405,9 @@ shishi_tkts_write (Shishi_tkts * tkts, FILE * fh)
   int res;
   int i;
 
+  if (!tkts)
+    return SHISHI_INVALID_TKTS;
+
   for (i = 0; i < tkts->ntkts; i++)
     {
       res = shishi_kdcrep_print
@@ -456,6 +460,9 @@ shishi_tkts_expire (Shishi_tkts * tkts)
   int warn = 0;
   int i = 0;
 
+  if (!tkts)
+    return SHISHI_INVALID_TKTS;
+
   while (i < tkts->ntkts)
     {
       if (shishi_tkt_expired_p (tkts->tkts[i]))
@@ -678,6 +685,9 @@ shishi_tkts_find (Shishi_tkts * tkts, Shishi_tkts_hint * hint)
 {
   int i;
 
+  if (!tkts)
+    return NULL;
+
   if (VERBOSENOISE (tkts->handle))
     {
       fprintf (stderr, "Searching tickets... ");
